@@ -19,6 +19,10 @@
  * USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -27,6 +31,8 @@
 
 #include "common.h"
 
+const char *program_name = "inspect";
+
 START_TEST (test_inspect_command)
 {
 	pipecmd *cmd;
