@@ -19,6 +19,10 @@
  * USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -30,6 +34,8 @@
 
 #include "common.h"
 
+const char *program_name = "redirect";
+
 START_TEST (test_redirect_files)
 {
 	char *template = xstrdup ("testtmp.XXXXXX");
@@ -56,6 +62,9 @@ START_TEST (test_redirect_files)
 
 	fclose (fh);
 	unlink (template);
+
+	pipeline_free (p);
+	free (template);
 }
 END_TEST
 
